@@ -1,4 +1,5 @@
-import re, sys
+import re
+import sys
 f_in = open(sys.argv[1], 'r')
 f_out = open(sys.argv[2], 'w')
 for line in f_in:
