@@ -1,35 +1,35 @@
 /*
- *  Copyright (C) 2004-2021 Edward F. Valeev
+ *  Copyright (C) 2004-2024 Edward F. Valeev
  *
- *  This file is part of Libint.
+ *  This file is part of Libint library.
  *
- *  Libint is free software: you can redistribute it and/or modify
+ *  Libint library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  Libint is distributed in the hope that it will be useful,
+ *  Libint library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
  *  You should have received a copy of the GNU Lesser General Public License
- *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Libint library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
 #ifndef _libint2_include_libint2_util_deprecated_h_
 #define _libint2_include_libint2_util_deprecated_h_
 
-#ifndef DEPRECATED  // avoid clashing with previous definitions
+#ifndef LIBINT2_DEPRECATED  // avoid clashing with previous definitions
 #if __cplusplus >= 201402L
-#define DEPRECATED [[deprecated]]
+#define LIBINT2_DEPRECATED [[deprecated]]
 #elif defined(__GNUC__)
-#define DEPRECATED __attribute__((deprecated))
+#define LIBINT2_DEPRECATED __attribute__((deprecated))
 #else
-#pragma message("WARNING: You need to implement DEPRECATED for this compiler")
-#define DEPRECATED
+#pragma message("WARNING: You need to implement LIBINT2_DEPRECATED for this compiler")
+#define LIBINT2_DEPRECATED
 #endif
-#endif  // not defined(DEPRECATED)
+#endif  // not defined(LIBINT2_DEPRECATED)
 
 #endif /* header guard */
