@@ -1,26 +1,27 @@
 /*
- *  Copyright (C) 2004-2021 Edward F. Valeev
+ *  Copyright (C) 2004-2024 Edward F. Valeev
  *
- *  This file is part of Libint.
+ *  This file is part of Libint compiler.
  *
- *  Libint is free software: you can redistribute it and/or modify
+ *  Libint compiler is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  Libint is distributed in the hope that it will be useful,
+ *  Libint compiler is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Libint compiler.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
-#include <fstream>
 #include <comp_deriv_gauss.h>
 
+#include <fstream>
+
 using namespace libint2;
 
 CR_DerivGauss_GenericInstantiator CR_DerivGauss_GenericInstantiator::instance_;
@@ -33,11 +34,10 @@ CR_DerivGauss_GenericInstantiator::~CR_DerivGauss_GenericInstantiator() {
 
     ofile << "#include \"libint2.h\"" << std::endl;
     ofile << "#include \"GenericGaussDeriv.impl.h\"" << std::endl << std::endl;
-    for(auto v=template_instances_.begin();
-        v != template_instances_.end();
-        ++v) {
-      ofile << "template struct libint2::GenericGaussDeriv<" << v->first << "," << (v->second ? "true" : "false")
-            << ">;" << std::endl;
+    for (auto v = template_instances_.begin(); v != template_instances_.end();
+         ++v) {
+      ofile << "template struct libint2::GenericGaussDeriv<" << v->first << ","
+            << (v->second ? "true" : "false") << ">;" << std::endl;
     }
   }
 }
@@ -47,8 +47,6 @@ CR_DerivGauss_GenericInstantiator::instance() {
   return instance_;
 }
 
-void
-CR_DerivGauss_GenericInstantiator::add(unsigned int L, bool vectorize) {
+void CR_DerivGauss_GenericInstantiator::add(unsigned int L, bool vectorize) {
   template_instances_.insert(std::make_pair(L, vectorize));
 }
-
