@@ -1,20 +1,20 @@
 /*
- *  Copyright (C) 2004-2021 Edward F. Valeev
+ *  Copyright (C) 2004-2024 Edward F. Valeev
  *
- *  This file is part of Libint.
+ *  This file is part of Libint compiler.
  *
- *  Libint is free software: you can redistribute it and/or modify
+ *  Libint compiler is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  Libint is distributed in the hope that it will be useful,
+ *  Libint compiler is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with Libint compiler.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -55,9 +55,9 @@ namespace libint2 {
       /* This "constructor" takes basis function sets, in Mulliken ordering.
          Returns a pointer to a unique instance, a la Singleton
       */
-      static const SafePtr<R2dotR2G12_11_11> Instance(const BFS& bra0, const BFS& ket0, const BFS& bra1, const BFS& ket1);
+      static const std::shared_ptr<R2dotR2G12_11_11> Instance(const BFS& bra0, const BFS& ket0, const BFS& bra1, const BFS& ket1);
       /// Returns a pointer to a unique instance, a la Singleton
-      static const SafePtr<R2dotR2G12_11_11> Instance(const BraType& bra, const KetType& ket, const AuxIndexType& aux);
+      static const std::shared_ptr<R2dotR2G12_11_11> Instance(const BraType& bra, const KetType& ket, const AuxIndexType& aux);
       ~R2dotR2G12_11_11();
 
       /// Comparison operator
@@ -87,7 +87,7 @@ namespace libint2 {
     typename R2dotR2G12_11_11<BFS>::SingletonManagerType
     R2dotR2G12_11_11<BFS>::singl_manager_(&R2dotR2G12_11_11<BFS>::key);
 #else
-#  error "USE_INT_KEY_TO_HASH must be set"
+#error "USE_INT_KEY_TO_HASH must be set"
 #endif
 
   template <class BFS>
@@ -116,24 +116,24 @@ namespace libint2 {
     }
 
   template <class BFS>
-    const SafePtr< R2dotR2G12_11_11<BFS> >
+    const std::shared_ptr< R2dotR2G12_11_11<BFS> >
     R2dotR2G12_11_11<BFS>::Instance(const BraType& bra, const KetType& ket, const AuxIndexType& aux)
     {
       typedef typename SingletonManagerType::value_type map_value_type;
       key_type key = compute_key(OperType(),bra,ket,aux);
       const map_value_type& val = singl_manager_.find(key);
       if (!val.second) {
-	SafePtr<R2dotR2G12_11_11> this_int(new R2dotR2G12_11_11<BFS>(bra,ket,aux));
-	// Use singl_manager_ to make sure this is a new object of this type
-	const typename SingletonManagerType::value_type& val = singl_manager_.find(this_int);
-	val.second->instid_ = val.first;
-	return val.second;
+std::shared_ptr<R2dotR2G12_11_11> this_int(new R2dotR2G12_11_11<BFS>(bra,ket,aux));
+// Use singl_manager_ to make sure this is a new object of this type
+const typename SingletonManagerType::value_type& val = singl_manager_.find(this_int);
+val.second->instid_ = val.first;
+return val.second;
       }
       return val.second;
     }
 
   template <class BFS>
-    const SafePtr< R2dotR2G12_11_11<BFS> >
+    const std::shared_ptr< R2dotR2G12_11_11<BFS> >
     R2dotR2G12_11_11<BFS>::Instance(const BFS& bra0, const BFS& ket0, const BFS& bra1, const BFS& ket1)
     {
 #if USE_BRAKET_H
@@ -143,7 +143,7 @@ namespace libint2 {
       BFSRef ket0_ref(ket0);
       BFSRef ket1_ref(ket1);
 #else
-      typedef SafePtr<BFS> BFSRef;
+      typedef std::shared_ptr<BFS> BFSRef;
       BFSRef bra0_ref(new BFS(bra0));
       BFSRef bra1_ref(new BFS(bra1));
       BFSRef ket0_ref(new BFS(ket0));
@@ -174,13 +174,13 @@ namespace libint2 {
     R2dotR2G12_11_11<BFS>::label() const
     {
       if (label_.empty()) {
-	ostringstream os;
-	os << "(" << parent_type::bra_.member(0,0)->label() << " "
-	   << parent_type::ket_.member(0,0)->label()
-	   << " | r_2^2 * G12 | "
-	   << parent_type::bra_.member(1,0)->label() << " "
-	   << parent_type::ket_.member(1,0)->label() << ")";
-	label_ = os.str();
+ostringstream os;
+os << "(" << parent_type::bra_.member(0,0)->label() << " "
+   << parent_type::ket_.member(0,0)->label()
+   << " | r_2^2 * G12 | "
+   << parent_type::bra_.member(1,0)->label() << " "
+   << parent_type::ket_.member(1,0)->label() << ")";
+label_ = os.str();
       }
       return label_;
     };
@@ -197,7 +197,6 @@ namespace libint2 {
   typedef R2dotR2G12_11_11<CGShell> R2dotR2G12_11_11_sq;
   typedef R2dotR2G12_11_11<CGF> R2dotR2G12_11_11_int;
 #endif
-};
+};  // namespace libint2
 
 #endif
-
